@@ -25,11 +25,13 @@ RESERVED_KEYWORDS = [
 UNRESERVED_KEYWORDS = [
     "AUTO",
     "CATALOG",
+    "CDC",
     "COMPENSATION",
     "CRON",
     "ENFORCED",
     "EVOLUTION",
     "FEATURE",
+    "FLOW",
     "IDENTIFIER",
     "MANAGED",
     "MASK",
