@@ -20,6 +20,7 @@ from sqlfluff.core.parser import (
     Nothing,
     OneOf,
     OptionallyBracketed,
+    ParseMode,
     Ref,
     RegexLexer,
     RegexParser,
@@ -52,6 +53,7 @@ The dialect for `DuckDB <https://duckdb.org/>`_.
 
 duckdb_dialect.sets("reserved_keywords").update(
     [
+        "LAMBDA",
         "PIVOT",
         "PIVOT_LONGER",
         "PIVOT_WIDER",
@@ -62,13 +64,25 @@ duckdb_dialect.sets("reserved_keywords").update(
 duckdb_dialect.sets("unreserved_keywords").update(
     [
         "ANTI",
+        "APPEND",
         "ASOF",
+        "COMPRESSION",
+        "COMPRESSION_LEVEL",
+        "GLOB",
         "MACRO",
         "MAP",
+        "OVERWRITE",
+        "OVERWRITE_OR_IGNORE",
+        "PARQUET_VERSION",
+        "PARTITION_BY",
         "POSITIONAL",
+        "PROGRAM",
+        "ROW_GROUP_SIZE",
+        "ROW_GROUP_SIZE_BYTES",
         "SEMI",
         "STRUCT",
         "VIRTUAL",
+        "WRITE_PARTITION_COLUMNS",
     ]
 )
 
@@ -76,6 +90,7 @@ duckdb_dialect.add(
     LambdaArrowSegment=StringParser("->", SymbolSegment, type="lambda_arrow"),
     OrIgnoreGrammar=Sequence("OR", "IGNORE"),
     EqualsSegment_a=StringParser("==", ComparisonOperatorSegment),
+    UnpackingOperatorSegment=TypedParser("star", SymbolSegment, "unpacking_operator"),
 )
 
 duckdb_dialect.replace(
@@ -130,7 +145,9 @@ duckdb_dialect.replace(
         Ref("NamedArgumentSegment"),
         Ref("ExpressionSegment"),
     ),
-    ColumnsExpressionNameGrammar=Ref.keyword("COLUMNS"),
+    ColumnsExpressionNameGrammar=Sequence(
+        Ref("UnpackingOperatorSegment", optional=True), "COLUMNS"
+    ),
     # Uses grammar for LT06 support
     ColumnsExpressionGrammar=Sequence(
         Ref("ColumnsExpressionFunctionNameSegment"),
@@ -144,13 +161,42 @@ duckdb_dialect.replace(
         "single_quote", IdentifierSegment, type="quoted_identifier", casefold=str.lower
     ),
     ListComprehensionGrammar=Ref("ListComprehensionExpressionSegment"),
+    # non-ANSI IN operator defined for string, list, and map
+    # https://duckdb.org/docs/stable/sql/expressions/in
+    InOperatorGrammar=Sequence(
+        Ref.keyword("NOT", optional=True),
+        "IN",
+        OneOf(
+            Bracketed(
+                OneOf(
+                    Delimited(Ref("Expression_A_Grammar"), allow_trailing=True),
+                    Ref("SelectableGrammar"),
+                ),
+                parse_mode=ParseMode.GREEDY,
+            ),
+            Ref("FunctionSegment"),
+            Ref("ArrayLiteralSegment"),
+            Ref("QuotedLiteralSegment"),
+            Ref("ColumnReferenceSegment"),
+        ),
+    ),
     ComparisonOperatorGrammar=ansi_dialect.get_grammar(
         "ComparisonOperatorGrammar"
     ).copy(
         insert=[
             Ref("EqualsSegment_a"),
+            Ref("GlobOperatorSegment"),
         ]
     ),
+    LikeGrammar=postgres_dialect.get_grammar("LikeGrammar").copy(
+        insert=[Ref.keyword("GLOB")],
+    ),
+    FilterClauseGrammar=Sequence(
+        "FILTER",
+        Bracketed(
+            Sequence(Ref.keyword("WHERE", optional=True), Ref("ExpressionSegment"))
+        ),
+    ),
 )
 
 duckdb_dialect.insert_lexer_matchers(
@@ -388,7 +434,7 @@ class WildcardExcludeExpressionSegment(BaseSegment):
         "EXCLUDE",
         OneOf(
             Ref("ColumnReferenceSegment"),
-            Bracketed(Delimited(Ref("ColumnReferenceSegment"))),
+            Bracketed(Delimited(Ref("ColumnReferenceSegment"), allow_trailing=True)),
         ),
     )
 
@@ -406,6 +452,7 @@ class WildcardReplaceExpressionSegment(BaseSegment):
                         Ref("BaseExpressionElementGrammar"),
                         Ref("AliasExpressionSegment", optional=True),
                     ),
+                    allow_trailing=True,
                 )
             ),
             Sequence(
@@ -416,6 +463,46 @@ class WildcardReplaceExpressionSegment(BaseSegment):
     )
 
 
+class WildcardRenameExpressionSegment(BaseSegment):
+    """A `RENAME` clause within a wildcard expression."""
+
+    type = "wildcard_rename"
+    match_grammar = Sequence(
+        "RENAME",
+        OneOf(
+            Bracketed(
+                Delimited(
+                    Sequence(
+                        Ref("BaseExpressionElementGrammar"),
+                        Ref("AliasExpressionSegment", optional=True),
+                    ),
+                    allow_trailing=True,
+                )
+            ),
+            Sequence(
+                Ref("BaseExpressionElementGrammar"),
+                Ref("AliasExpressionSegment", optional=True),
+            ),
+        ),
+    )
+
+
+class WildcardPatternMatchingSegment(BaseSegment):
+    """A pattern matching operator clause within a wildcard expression."""
+
+    type = "wildcard_pattern_matching"
+    match_grammar = OneOf(
+        Ref("LikeExpressionGrammar"),
+        Sequence(
+            OneOf(
+                Ref("LikeOperatorSegment"),
+                Ref("GlobOperatorSegment"),
+            ),
+            Ref("QuotedLiteralSegment"),
+        ),
+    )
+
+
 class WildcardExpressionSegment(ansi.WildcardExpressionSegment):
     """An extension of the star expression for DuckDB."""
 
@@ -424,7 +511,14 @@ class WildcardExpressionSegment(ansi.WildcardExpressionSegment):
         Ref("WildcardIdentifierSegment"),
         # Optional EXCLUDE or REPLACE clause
         Ref("WildcardExcludeExpressionSegment", optional=True),
-        Ref("WildcardReplaceExpressionSegment", optional=True),
+        OneOf(
+            Sequence(
+                Ref("WildcardReplaceExpressionSegment", optional=True),
+                Ref("WildcardRenameExpressionSegment", optional=True),
+            ),
+            Ref("WildcardPatternMatchingSegment"),
+            optional=True,
+        ),
     )
 
 
@@ -459,8 +553,8 @@ class ColumnsExpressionFunctionContentsSegment(
         Bracketed(
             OneOf(
                 Ref("WildcardExpressionSegment"),
-                Ref("QuotedLiteralSegment"),
                 Ref("LambdaExpressionSegment"),
+                Ref("BaseExpressionElementGrammar"),
             ),
         ),
     )
@@ -469,18 +563,29 @@ class ColumnsExpressionFunctionContentsSegment(
 class LambdaExpressionSegment(BaseSegment):
     """Lambda function used in a function or columns expression.
 
-    https://duckdb.org/docs/sql/functions/lambda
+    https://duckdb.org/docs/stable/sql/functions/lambda
     https://duckdb.org/docs/sql/expressions/star#columns-lambda-function
     """
 
     type = "lambda_function"
-    match_grammar = Sequence(
-        OneOf(
-            Ref("ParameterNameSegment"),
-            Bracketed(Delimited(Ref("ParameterNameSegment"))),
+    match_grammar = OneOf(
+        Sequence(
+            OneOf(
+                Ref("ParameterNameSegment"),
+                Bracketed(Delimited(Ref("ParameterNameSegment"))),
+            ),
+            Ref("LambdaArrowSegment"),
+            Ref("ExpressionSegment"),
+        ),
+        Sequence(
+            "LAMBDA",
+            OneOf(
+                Ref("ParameterNameSegment"),
+                Bracketed(Delimited(Ref("ParameterNameSegment"))),
+            ),
+            Ref("ColonSegment"),
+            Ref("ExpressionSegment"),
         ),
-        Ref("LambdaArrowSegment"),
-        Ref("ExpressionSegment"),
     )
 
 
@@ -890,3 +995,105 @@ class CreateTypeStatementSegment(postgres.CreateTypeStatementSegment):
             Sequence("UNION", Ref("StructTypeSchemaSegment")),
         ),
     )
+
+
+class CopyStatementSegment(postgres.CopyStatementSegment):
+    """A `COPY` statement.
+
+    As specified in https://duckdb.org/docs/stable/sql/statements/copy.html
+    """
+
+    type = "copy_statement"
+
+    _target_subset = OneOf(
+        Ref("QuotedLiteralSegment"), Sequence("PROGRAM", Ref("QuotedLiteralSegment"))
+    )
+
+    _table_definition = Sequence(
+        Ref("TableReferenceSegment"),
+        Bracketed(Delimited(Ref("ColumnReferenceSegment")), optional=True),
+    )
+
+    # DuckDB COPY TO options
+    # https://duckdb.org/docs/stable/sql/statements/copy.html
+    _copy_to_option = Sequence(
+        Ref.keyword("WITH", optional=True),
+        Bracketed(
+            Delimited(
+                OneOf(
+                    Sequence("FORMAT", Ref("SingleIdentifierGrammar")),
+                    Sequence(
+                        "OVERWRITE_OR_IGNORE",
+                        Ref("BooleanLiteralGrammar", optional=True),
+                    ),
+                    Sequence("OVERWRITE", Ref("BooleanLiteralGrammar", optional=True)),
+                    Sequence("APPEND", Ref("BooleanLiteralGrammar", optional=True)),
+                    Sequence(
+                        "PARTITION_BY",
+                        OneOf(
+                            Bracketed(Delimited(Ref("ColumnReferenceSegment"))),
+                            Ref("ColumnReferenceSegment"),
+                        ),
+                    ),
+                    Sequence(
+                        "WRITE_PARTITION_COLUMNS",
+                        Ref("BooleanLiteralGrammar", optional=True),
+                    ),
+                    Sequence(
+                        "COMPRESSION",
+                        OneOf(
+                            Ref("QuotedLiteralSegment"),
+                            Ref("SingleIdentifierGrammar"),
+                        ),
+                    ),
+                    Sequence("COMPRESSION_LEVEL", Ref("NumericLiteralSegment")),
+                    Sequence("ROW_GROUP_SIZE_BYTES", Ref("NumericLiteralSegment")),
+                    Sequence("ROW_GROUP_SIZE", Ref("NumericLiteralSegment")),
+                    Sequence("PARQUET_VERSION", Ref("QuotedLiteralSegment")),
+                )
+            )
+        ),
+        optional=True,
+    )
+
+    # DuckDB COPY FROM options (keeping PostgreSQL compatibility for now)
+    _copy_from_option = postgres.CopyStatementSegment._option
+
+    match_grammar = Sequence(
+        "COPY",
+        OneOf(
+            # COPY TO
+            Sequence(
+                OneOf(_table_definition, Bracketed(Ref("SelectableGrammar"))),
+                "TO",
+                Ref("QuotedLiteralSegment"),
+                _copy_to_option,
+            ),
+            # COPY FROM
+            Sequence(
+                _table_definition,
+                "FROM",
+                Ref("QuotedLiteralSegment"),
+                _copy_from_option,
+            ),
+        ),
+    )
+
+
+class ArrayLiteralSegment(BaseSegment):
+    """An array literal segment.
+
+    An unqualified array literal:
+    e.g. [1, 2, 3]
+
+    DuckDB allows for trailing commas:
+    e.g. [1, 2, 3,]
+    """
+
+    type = "array_literal"
+    match_grammar: Matchable = Bracketed(
+        Delimited(
+            Ref("BaseExpressionElementGrammar"), optional=True, allow_trailing=True
+        ),
+        bracket_type="square",
+    )
