@@ -206,7 +206,9 @@ redshift_dialect.replace(
             r"#?([A-Z_]+|[0-9]+[A-Z_$])[A-Z0-9_$]*",
             IdentifierSegment,
             type="naked_identifier",
-            anti_template=r"^(" + r"|".join(dialect.sets("reserved_keywords")) + r")$",
+            anti_template=r"^("
+            + r"|".join(sorted(dialect.sets("reserved_keywords")))
+            + r")$",
             casefold=str.lower,
         )
     ),
