@@ -26,11 +26,13 @@ from sqlfluff.core.parser import (
     Ref,
     RegexLexer,
     RegexParser,
+    SegmentGenerator,
     Sequence,
     StringLexer,
     StringParser,
     SymbolSegment,
     TypedParser,
+    WordSegment,
 )
 from sqlfluff.dialects import dialect_ansi as ansi
 from sqlfluff.dialects.dialect_vertica_keywords import (
@@ -39,7 +41,12 @@ from sqlfluff.dialects.dialect_vertica_keywords import (
 )
 
 ansi_dialect = load_raw_dialect("ansi")
-vertica_dialect = ansi_dialect.copy_as("vertica")
+vertica_dialect = ansi_dialect.copy_as(
+    "vertica",
+    formatted_name="Vertica",
+    docstring="""The dialect for
+`Vertica <https://www.vertica.com/documentation/vertica/all/>`_.""",
+)
 
 vertica_dialect.insert_lexer_matchers(
     # Allow ::! operator as in
@@ -102,6 +109,11 @@ vertica_dialect.patch_lexer_matchers(
                 "escape_replacements": [(r'""', '"')],
             },
         ),
+        RegexLexer(
+            "word",
+            r"[\p{L}_][\p{L}\p{N}_$]*",
+            WordSegment,
+        ),
     ]
 )
 
@@ -363,18 +375,7 @@ vertica_dialect.replace(
         Ref("Tail_Recurse_Expression_A_Grammar"),
         AnyNumberOf(
             OneOf(
-                Sequence(
-                    Sequence(
-                        Ref.keyword("NOT", optional=True),
-                        Ref("LikeGrammar"),
-                    ),
-                    Ref("Expression_A_Grammar"),
-                    Sequence(
-                        Ref.keyword("ESCAPE"),
-                        Ref("Tail_Recurse_Expression_A_Grammar"),
-                        optional=True,
-                    ),
-                ),
+                Ref("LikeExpressionGrammar"),
                 Sequence(
                     Ref("BinaryOperatorGrammar"),
                     Ref("Tail_Recurse_Expression_A_Grammar"),
@@ -474,6 +475,47 @@ vertica_dialect.replace(
     QuotedIdentifierSegment=TypedParser(
         "double_quote", IdentifierSegment, type="quoted_identifier", casefold=str.upper
     ),
+    NakedIdentifierSegment=SegmentGenerator(
+        # Generate the anti template from the set of reserved keywords
+        lambda dialect: RegexParser(
+            # https://docs.vertica.com/24.3.x/en/sql-reference/language-elements/identifiers/
+            # Unquoted SQL identifiers must begin with one of the following:
+            # * Non-Unicode letters: A–Z or a-z
+            # -- /actually Vertica accepts also non-ASCII UTF-8 Unicode
+            # characters here, which is not well documented/
+            # * Underscore (_)
+            # Subsequent characters in an identifier can be any combination of
+            # the following:
+            # * Non-Unicode letters: A–Z or a-z
+            # * Underscore (_)
+            # * Digits(0–9)
+            # * Unicode letters (letters with diacriticals or not in the Latin
+            # alphabet), unsupported for model names
+            # * Dollar sign ($), unsupported for model names
+            #
+            # Vertica accepts **non-ASCII UTF-8 Unicode characters** for table
+            # names, column names, and other identifiers,
+            # extending the cases where upper/lower case distinctions are
+            # ignored (case-folded) to all alphabets,
+            # including Latin, Cyrillic, and Greek.
+            # \p{L} matches any kind of letter from any language;
+            # \p{N} matches any kind of numeric character in any script
+            r"[\p{L}_][\p{L}\p{N}$_]*",
+            IdentifierSegment,
+            type="naked_identifier",
+            anti_template=r"^("
+            + r"|".join(sorted(dialect.sets("reserved_keywords")))
+            + r")$",
+            casefold=str.upper,
+        )
+    ),
+    ParameterNameSegment=RegexParser(
+        # need to cover cases where non-ascii word is parameter
+        # like ```ALTER TABLE some_table TO utf8_identifier_eg_Verkäufer;```
+        r"[\p{L}_][\p{L}\p{N}$_]*",
+        CodeSegment,
+        type="parameter",
+    ),
 )
 
 
@@ -1613,11 +1655,7 @@ class DatatypeSegment(ansi.DatatypeSegment):
     match_grammar: Matchable = Sequence(
         OneOf(
             # Date / Datetime
-            Sequence(
-                OneOf("TIME", "TIMESTAMP"),
-                Bracketed(Ref("NumericLiteralSegment"), optional=True),
-                Sequence(OneOf("WITH", "WITHOUT"), "TIME", "ZONE", optional=True),
-            ),
+            Ref("TimeWithTZGrammar"),
             "DATE",
             "DATETIME",
             "SMALLDATETIME",
@@ -1831,17 +1869,7 @@ class FunctionSegment(ansi.FunctionSegment):
             # rather than identifiers.
             Sequence(
                 Ref("DatePartFunctionNameSegment"),
-                Bracketed(
-                    Delimited(
-                        Ref("DatetimeUnitSegment"),
-                        Ref(
-                            "FunctionContentsGrammar",
-                            # The brackets might be empty for some functions...
-                            optional=True,
-                        ),
-                    ),
-                    parse_mode=ParseMode.GREEDY,
-                ),
+                Ref("DateTimeFunctionContentsSegment"),
             ),
         ),
         Ref("ColumnsExpressionGrammar"),
@@ -1855,14 +1883,7 @@ class FunctionSegment(ansi.FunctionSegment):
                         Ref("ValuesClauseSegment"),
                     ),
                 ),
-                Bracketed(
-                    Ref(
-                        "FunctionContentsGrammar",
-                        # The brackets might be empty for some functions...
-                        optional=True,
-                    ),
-                    parse_mode=ParseMode.GREEDY,
-                ),
+                Ref("FunctionContentsSegment"),
             ),
             AnySetOf(Ref("PostFunctionGrammar")),
         ),
@@ -2078,7 +2099,8 @@ class AliasExpressionSegment(ansi.AliasExpressionSegment):
 
     match_grammar: Matchable = OneOf(
         Sequence(
-            Ref.keyword("AS", optional=True),
+            Indent,
+            Ref("AsAliasOperatorSegment", optional=True),
             OneOf(
                 Sequence(
                     Ref("SingleIdentifierGrammar"),
@@ -2088,11 +2110,12 @@ class AliasExpressionSegment(ansi.AliasExpressionSegment):
                 Sequence(Bracketed(Ref("SingleIdentifierListSegment"), optional=True)),
                 Ref("SingleQuotedIdentifierSegment"),
             ),
+            Dedent,
         ),
         # Some functions alias several columns in brackets () like mapkeys or explode
         Sequence(
             Indent,
-            Ref.keyword("AS"),
+            Ref("AsAliasOperatorSegment", optional=True),
             Bracketed(Delimited(Ref("ColumnReferenceSegment"))),
             Dedent,
         ),
