@@ -13,6 +13,11 @@ from sqlfluff.core.parser.segments.keyword import KeywordSegment
 from sqlfluff.core.rules import BaseRule, EvalResultType, LintResult, RuleContext
 from sqlfluff.core.rules.crawlers import SegmentSeekerCrawler
 from sqlfluff.core.rules.fix import LintFix
+from sqlfluff.dialects.dialect_ansi import (
+    ExpressionSegment,
+    JoinClauseSegment,
+    JoinOnConditionSegment,
+)
 
 
 class Rule_CV12(BaseRule):
@@ -103,9 +108,17 @@ class Rule_CV12(BaseRule):
                     no_recursive_seg_type=["select_statement"],
                 )
             )
+            encountered_function = self._get_from_expression_element_function(
+                join_table_reference
+            )
+            if encountered_function in ("UNNEST",):
+                # If UNNEST function is used, disregard lack of condition
+                continue
+
             encountered_references.add(
                 self._get_from_expression_element_alias(join_table_reference)
             )
+
             join_clause_keywords = [
                 seg for seg in join_clause.segments if seg.type == "keyword"
             ]
@@ -172,18 +185,30 @@ class Rule_CV12(BaseRule):
                     ].is_type("whitespace", "binary_operator"):
                         join_clause_fix_segments.pop()
 
+                    join_on_expression = ExpressionSegment(
+                        tuple(join_clause_fix_segments),
+                    )
+                    join_on = JoinOnConditionSegment(
+                        (
+                            KeywordSegment("ON"),
+                            WhitespaceSegment(),
+                            join_on_expression,
+                        )
+                    )
+                    join_clause_segment = JoinClauseSegment(
+                        (
+                            *join_clause.segments,
+                            WhitespaceSegment(),
+                            join_on,
+                        )
+                    )
+
                     yield LintResult(
                         anchor=join_clause,
                         fixes=[
                             LintFix.replace(
                                 join_clause,
-                                edit_segments=[
-                                    *join_clause.segments,
-                                    WhitespaceSegment(),
-                                    KeywordSegment("ON"),
-                                    WhitespaceSegment(),
-                                    *join_clause_fix_segments,
-                                ],
+                                edit_segments=[join_clause_segment],
                             )
                         ],
                     )
@@ -245,6 +270,32 @@ class Rule_CV12(BaseRule):
 
         return alias_str
 
+    @staticmethod
+    def _get_from_expression_element_function(from_expr_element: BaseSegment) -> str:
+        """Extract the function name from a from_expression_element if present."""
+
+        def get_segment_or_default(
+            segment: BaseSegment, child_type: str, default: BaseSegment
+        ) -> BaseSegment:
+            """Helper to safely get a child segment or return a default."""
+            child = segment.get_child(child_type)
+            return child if child else default
+
+        table_expr = get_segment_or_default(
+            from_expr_element, "table_expression", from_expr_element
+        )
+
+        if "function" not in table_expr.direct_descendant_type_set:
+            return ""
+
+        function = get_segment_or_default(table_expr, "function", table_expr)
+        function_name = get_segment_or_default(function, "function_name", table_expr)
+        function_id = get_segment_or_default(
+            function_name, "function_name_identifier", table_expr
+        )
+
+        return function_id.raw_upper
+
     @staticmethod
     def _is_where_clause_simplifable(where_clause: BaseSegment) -> bool:
         assert where_clause.is_type("where_clause")
